@@ -28,7 +28,7 @@
 #endif
 
 #ifdef WITH_HILDON
-#include <hildon-widgets/hildon-color-button.h>
+#include <hildon/hildon-color-button.h>
 #endif
 
 #ifndef DATES_PLATFORM_create_main_window
@@ -47,6 +47,7 @@ create_main_window (DatesData * d, GtkWidget * toolbar,
 	GtkWidget *find_close_button;
 	GtkWidget *image;
 	GtkWidget *scrolled_window;
+	gchar* tmp_str;
 
 	d->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (d->main_window), _("Dates"));
@@ -67,7 +68,10 @@ create_main_window (DatesData * d, GtkWidget * toolbar,
 	gtk_box_pack_start (GTK_BOX (main_vbox), d->header_eventbox,
 						FALSE, FALSE, 0);
 
-	d->header_label = gtk_label_new (_("<big><b>Dates</b></big>"));
+	tmp_str = g_strdup_printf ("<big><b>%s</b></big>", _("Dates"));
+	d->header_label = gtk_label_new (tmp_str);
+	g_free (tmp_str);
+
 	gtk_widget_show (d->header_label);
 	gtk_container_add (GTK_CONTAINER (d->header_eventbox), d->header_label);
 	gtk_label_set_use_markup (GTK_LABEL (d->header_label), TRUE);
@@ -538,7 +542,7 @@ create_time_dialog (DatesData * d)
 	gtk_box_pack_start (GTK_BOX (vbox1), d->time_table, TRUE, TRUE, 0);
 	gtk_table_set_col_spacings (GTK_TABLE (d->time_table), 6);
 
-	time_separator_label = gtk_label_new (_("<b>:</b>"));
+	time_separator_label = gtk_label_new ("<b>:</b>");
 	gtk_widget_show (time_separator_label);
 	gtk_table_attach (GTK_TABLE (d->time_table), time_separator_label,
 					  1, 2, 1, 2,
@@ -773,6 +777,7 @@ calendar_do_new_dialog (GtkWindow *parent, DatesData *d)
 	GtkCellRenderer *renderer = NULL;
 
 	GdkColor colour;
+	gchar* tmp_str;
 
 	const gchar *uri = NULL;
 
@@ -799,7 +804,9 @@ calendar_do_new_dialog (GtkWindow *parent, DatesData *d)
 	frame = gtk_frame_new (NULL);
 
 	/* Create the label */
-	label = gtk_label_new (_("<b>Calendar</b>"));
+	tmp_str = g_strdup_printf ("<b>%s</b>", _("Calendar"));
+	label = gtk_label_new (tmp_str);
+	g_free(tmp_str);
 
 	/* Turn on the markup for the label */
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -1051,8 +1058,7 @@ calendar_do_new_dialog (GtkWindow *parent, DatesData *d)
 #else
 
 #ifdef WITH_HILDON
-			hildon_color = hildon_color_button_get_color (HILDON_COLOR_BUTTON(color_button));
-			colour = *hildon_color;
+			hildon_color_button_get_color (HILDON_COLOR_BUTTON(color_button), &colour);
 #else
 			gtk_color_button_get_color (GTK_COLOR_BUTTON(color_button), &colour);
 #endif
@@ -1167,6 +1173,7 @@ calendar_do_edit_dialog (GtkWindow *parent, ESource *source, DatesData *d)
 	const gchar *name = NULL;
 	const gchar *uri = NULL;
 	gchar *type = NULL;
+        gchar *tmp_str;
 
 	gboolean remote = FALSE;
 
@@ -1210,7 +1217,9 @@ calendar_do_edit_dialog (GtkWindow *parent, ESource *source, DatesData *d)
 	frame = gtk_frame_new (NULL);
 
 	/* Create the label */
-	label = gtk_label_new (_("<b>Calendar</b>"));
+	tmp_str = g_strdup_printf ("<b>%s</b>", _("Calendar"));
+	label = gtk_label_new (tmp_str);
+	g_free(tmp_str);
 
 	/* Turn on the markup for the label */
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -1437,9 +1446,7 @@ calendar_do_edit_dialog (GtkWindow *parent, ESource *source, DatesData *d)
 			new_colour = owl_colour_button_get_colour (OWL_COLOUR_BUTTON (color_button));
 #else
 #ifdef WITH_HILDON
-			GdkColor *hildon_color;
-			hildon_color = hildon_color_button_get_color (HILDON_COLOR_BUTTON(color_button));
-			colour = *hildon_color;
+			hildon_color_button_get_color (HILDON_COLOR_BUTTON(color_button), &colour);
 #else
 			gtk_color_button_get_color (GTK_COLOR_BUTTON(color_button), &colour);
 #endif			
@@ -1872,7 +1879,7 @@ create_main_menu (DatesData * d, GtkAccelGroup ** accel_group)
 	gtk_widget_show (sources_menuitem);
 	gtk_container_add (GTK_CONTAINER (menuitem1_menu), sources_menuitem);
 
-	import_menuitem = gtk_menu_item_new_with_mnemonic (_("_Import"));
+	import_menuitem = gtk_menu_item_new_with_mnemonic (_("_Import..."));
 	gtk_widget_show (import_menuitem);
 	gtk_container_add (GTK_CONTAINER (menuitem1_menu), import_menuitem);
 
@@ -2137,7 +2144,7 @@ void dates_platform_import_dialog (DatesData *d)
      * about with sizing.
      */
 
-    open_dialog = gtk_file_chooser_dialog_new ("Import calendar", GTK_WINDOW (d->main_window), 
+    open_dialog = gtk_file_chooser_dialog_new (_("Import calendar"), GTK_WINDOW (d->main_window), 
         GTK_FILE_CHOOSER_ACTION_OPEN,
         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
         GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
